===============
``definitions``
===============

.. automodule:: tt.definitions


``definitions.grammar`` module
------------------------------

.. automodule:: tt.definitions.grammar
    :members:


``definitions.operands`` module
-------------------------------

.. automodule:: tt.definitions.operands
    :members:


``definitions.operators`` module
--------------------------------

.. automodule:: tt.definitions.operators
    :members:
    :exclude-members: __weakref__
